@@ -1,4 +1,3 @@
-mod domain;
 /// VirusTotal API v3
 /// Clean & Simple interface to access the VirusTotal v3 REST api's
 /// ## Usage
@@ -12,10 +11,16 @@ mod domain;
 /// let vt_client = vt3::VtClient::new("YOUR API KEY");
 /// ```
 ///
-pub mod error;
+mod file;
 mod ip;
 mod url;
+mod domain;
+mod enterprise;
+pub use self::enterprise::retrohunt::SubmitJobRoot;
+
 mod utils;
+pub mod error;
+
 
 #[derive(Copy, Clone)]
 pub struct VtClient<'a> {
@@ -37,7 +42,7 @@ impl<'a> VtClient<'a> {
         VtClient {
             api_key,
             endpoint: "https://www.virustotal.com/api/v3",
-            user_agent: "rust-client/vt3-rs",
+            user_agent: "rust-client/vt3-rs+https://github.com/marirs/vt3-rs",
         }
     }
 }
